@@ -57,29 +57,30 @@ class MyPaintApp(App):
         return MyPaintWidget()
 
 
-def get_parser():
-    from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
-    parser = ArgumentParser(description=__doc__,
-                            formatter_class=ArgumentDefaultsHelpFormatter)
-    parser.add_argument("-m", "--model",
-                        dest="model",
-                        help="where is the model folder (with a info.yml)?",
-                        metavar="FOLDER",
-                        type=lambda x: utils.is_valid_folder(parser, x),
-                        default=utils.default_model())
-    parser.add_argument("-v", "--verbose",
-                        dest="verbose",
-                        help="show recording before and after preprocessing",
-                        action='store_true',
-                        default=False)
-    parser.add_argument("-n",
-                        dest="n", default=10, type=int,
-                        help="Show TOP-N results")
-    return parser
+# def get_parser():
+#     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
+#     parser = ArgumentParser(description=__doc__,
+#                             formatter_class=ArgumentDefaultsHelpFormatter)
+#     parser.add_argument("-m", "--model",
+#                         dest="model",
+#                         help="where is the model folder (with a info.yml)?",
+#                         metavar="FOLDER",
+#                         type=lambda x: utils.is_valid_folder(parser, x),
+#                         default=utils.default_model())
+#     parser.add_argument("-v", "--verbose",
+#                         dest="verbose",
+#                         help="show recording before and after preprocessing",
+#                         action='store_true',
+#                         default=False)
+#     parser.add_argument("-n",
+#                         dest="n", default=10, type=int,
+#                         help="Show TOP-N results")
+#     return parser
 
 
 if __name__ == '__main__':
-    args = get_parser().parse_args()
+    print("Start recording.")
+    #args = get_parser().parse_args()
     MyPaintApp().run()
     recording.append(last_stroke)
     last_stroke = []
@@ -87,10 +88,11 @@ if __name__ == '__main__':
     logging.info(recording)
     logging.info("Start evaluation...")
     # TODO: use args.verbose instead of True if possible
+    # args.model,
     results = utils.classify_single_recording(raw_data_json,
-                                              args.model,
+                                              utils.default_model(),
                                               True)
-    n = args.n
+    n = 10  # args.n
 
     # Print headline
     print("{0:18s} {1:5s}".format("LaTeX Code", "Prob"))
