@@ -50,9 +50,9 @@ def check_python_version():
 def check_python_modules():
     print("\033[1mCheck modules\033[0m")
     required_modules = ['argparse', 'matplotlib', 'natsort', 'MySQLdb',
-                        'cPickle', 'detl', 'theano', 'dropbox', 'yaml',
-                        'webbrowser', 'hashlib', 'shapely', 'numpy', 'wget',
-                        '_tkinter', 'jinja2']
+                        'cPickle', 'theano', 'dropbox', 'yaml',
+                        'webbrowser', 'hashlib', 'shapely', 'numpy',
+                        'jinja2']
     found = []
     for required_module in required_modules:
         try:
@@ -93,10 +93,6 @@ def check_python_modules():
         import numpy
         print("numpy version: %s (1.8.1 tested)" %
               numpy.__version__)
-    if "wget" in found:
-        import wget
-        print("wget version: %s (2.2 tested)" %
-              wget.__version__)
     if "yaml" in found:
         import yaml
         print("yaml version: %s (3.11 tested)" %
@@ -115,7 +111,7 @@ def check_python_modules():
 
 def check_executables():
     print("\033[1mCheck executables\033[0m")
-    required_executables = ["pfile_create"]
+    required_executables = ["pfile_create", "nntoolkit"]
     for executable in required_executables:
         path = which(executable)
         if path is None:
@@ -129,6 +125,7 @@ def check_executables():
 
 
 def main():
+    # TODO: Check if nntoolkit exists by config file entry
     check_python_version()
     check_python_modules()
     check_executables()
