@@ -378,10 +378,8 @@ def get_readable_time(t):
 
 
 def default_model():
-    """Get a path for a default value for the model.
-
-    scriptfile should be __file__ of the calling script
-    """
+    """Get a path for a default value for the model. Start searching in the
+    current directory."""
     project_root = get_project_root()
     models_dir = os.path.join(project_root, "models")
     curr_dir = os.getcwd()
